<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Api\ApiController;
use App\Http\Services\Api\SeminarSignUpService;
use App\Http\Requests\Api\SeminarSignUp\StoreRequest;

use Log;

class SeminarSignUpController extends ApiController
{
    
    private $seminarSignUpSv;
    
    public function __construct()
    {
        $this->seminarSignUpSv = new SeminarSignUpService();

    }

    // save data to db
    public function insertData(StoreRequest $request)
    {
        $trackNo = $request->input('trackNo', '');
        $lang = substr($trackNo, 0, 2);

        $firstName_orig = $request->input('firstName', '');
        $firstName = $this->safeEncrypt($firstName_orig, 'arm');

        $lastName_orig = $request->input('lastName', '');
        $lastName = $this->safeEncrypt($lastName_orig, 'arm');
        
        $companyName_orig = $request->input('companyName', '');
        $companyName = $this->safeEncrypt($companyName_orig, 'arm');
        
        $companyEmail_orig = $request->input('companyEmail', '');
        $companyEmail = $this->safeEncrypt($companyEmail_orig, 'arm');
        
        $backupEmail = $request->input('backupEmail', '');
        if (!is_null($backupEmail)) {
        
            $backupEmail_orig = $request->input('backupEmail', '');
            $backupEmail = $this->safeEncrypt($backupEmail_orig, 'arm');
        } else {
            $backupEmail_orig = '';
        }
        
        $phoneNumber_orig = $request->input('phoneNumber', '');
        $phoneNumber = $this->safeEncrypt($phoneNumber_orig, 'arm');
        
        $country = $request->input('country', '');
        $registeredSession = $request->input('registeredSession', '');
        $lunchOptions = $request->input('lunchOptions', '');
        $typeOfIndustry = $request->input('typeOfIndustry', '');
        $typeOfJob = $request->input('typeOfJob', '');
        $jobTitle = $request->input('jobTitle', '');
        $trackOfInterest = $request->input('trackOfInterest', '');
        $areaOfInterest = $request->input('areaOfInterest', '');
        $howToKnowAboutTheEvent = $request->input('howToKnowAboutTheEvent', '');
        $consentAcceptEmail = $request->input('consentAcceptEmail', '');
        $consentPrivacyPolicy = $request->input('consentPrivacyPolicy', '');
        
        $overOrNot = $this->seminarSignUpSv->overLimitOrNot($trackNo);          // true: 可報名 / false: 已額滿
        $duplicatedOrNot = $this->seminarSignUpSv->duplicatedOrNot($trackNo, $companyEmail, $phoneNumber);   // true: 可報名 / false: 已重複

        if ($overOrNot&&$duplicatedOrNot) {

            $this->seminarSignUpSv->insertData(
                $firstName, 
                $lastName, 
                $companyName, 
                $companyEmail, 
                $backupEmail, 
                $phoneNumber, 
                $country, 
                $trackNo, 
                $registeredSession,
                $lunchOptions,
                $typeOfIndustry,
                $typeOfJob,
                $jobTitle,
                $trackOfInterest,
                $areaOfInterest,
                $howToKnowAboutTheEvent,
                $consentAcceptEmail,
                $consentPrivacyPolicy,
            );
            $res = '報名成功';

            if ($lang=='TP'||$lang=='HS') {
                $this->mailToUser_TW($firstName_orig, $lastName_orig, $companyName_orig, $companyEmail_orig, $backupEmail_orig, 
                    $phoneNumber_orig, $country, $registeredSession, $lunchOptions, $typeOfIndustry, $typeOfJob, $jobTitle, $trackOfInterest);
            } elseif ($lang=='JP') {
                $this->mailToUser_JP($firstName_orig, $companyEmail_orig, $backupEmail_orig);
            } elseif ($lang=='KR') {
                $this->mailToUser_KR($firstName_orig, $lastName_orig, $companyName_orig, $companyEmail_orig, $backupEmail_orig, 
                $phoneNumber_orig, $country, /*$registeredSession, $lunchOptions, */$typeOfIndustry, $typeOfJob, $jobTitle, $trackOfInterest);
            } else {
                $this->mailToUser_EN($firstName_orig, $companyEmail_orig, $backupEmail_orig);
            }
            
        } elseif (!$overOrNot) {

            $res = '已達報名上限';
        } elseif (!$duplicatedOrNot) {

            $res = '已重複報名';
        }
        $data = [
            'res' => $res,
        ];
        
        return $this->apiResponse($data);
    }

    public function getData()
    {
        $list = $this->seminarSignUpSv->getData();
        
        $data = [
            'list' => $list
        ];
        
        return $this->apiResponse($data);
    }

    /**
     * 參數加解密模組: 加密部分，建議使用環境變數中的 secret key 作加解密種子
     */
    public function safeEncrypt(string $message, string $skey): string
    {
        $strArr = str_split(base64_encode($message));
        $strCount = count($strArr);
        foreach (str_split($skey) as $key => $value)
        $key < $strCount && $strArr[$key].=$value;
        return str_replace(array('=', ' ', '/'), array('O0O0O', 'o000o', 'oo00o'), join('', $strArr));
    }
    
    /**
     * 參數加解密模組: 解密部分，建議使用環境變數中的 secret key 作加解密種子
     */
    public function safeDecrypt(string $encrypted, string $skey): string
    {
        $strArr = str_split(str_replace(array('O0O0O', 'o000o', 'oo00o'), array('=', ' ', '/'), $encrypted), 2);
        $strCount = count($strArr);
        foreach (str_split($skey) as $key => $value)
        $key <= $strCount && isset($strArr[$key]) && $strArr[$key][1] === $value && $strArr[$key] = $strArr[$key][0];
        return base64_decode(join('', $strArr));
    }
    
    public function mailToUser_TW(
        string $firstName='', 
        string $lastName='', 
        string $companyName='',
        string $companyEmail='',
        string $backupEmail='',
        string $phoneNumber='',
        string $country='',
        string $registeredSession='',
        string $lunchOptions='',
        string $typeOfIndustry='',
        string $typeOfJob='',
        string $jobTitle='',
        string $trackOfInterest=''
        )
    {
        $data = array(
            'firstName' => $firstName,
            'lastName' => $lastName,
            'companyName' => $companyName,
            'companyEmail' => $companyEmail,
            'backupEmail' => $backupEmail,
            'phoneNumber' => $phoneNumber,
            'country' => $country,
            'registeredSession' => $registeredSession,
            'lunchOptions' => $lunchOptions,
            'typeOfIndustry' => $typeOfIndustry,
            'typeOfJob' => $typeOfJob,
            'jobTitle' => $jobTitle,
            'trackOfInterest' => $trackOfInterest,
        );

        if (strlen($backupEmail)>0) {
            \Mail::send(['text'=>'mailTW'], $data, function($message) use ($firstName, $companyEmail, $backupEmail) {
                $message->to($companyEmail, $firstName)->subject('報名成功');
                $message->cc($backupEmail, $firstName)->subject('報名成功');
                $message->from(env('MAIL_USERNAME'),env('MAIL_FROM_NAME'));
            });
        } else {
            \Mail::send(['text'=>'mailTW'], $data, function($message) use ($companyEmail, $firstName) {
                $message->to($companyEmail, $firstName)->subject('報名成功');
                $message->from(env('MAIL_USERNAME'),env('MAIL_FROM_NAME'));
            });
        }
    }

    public function mailToUser_JP(string $firstName='', string $companyEmail='', string $backupEmail='')
    {
        $data = array('name'=>$firstName);

        if ($backupEmail) {
            \Mail::send(['text'=>'mailJP'], $data, function($message) use ($companyEmail, $firstName, $backupEmail) {
                $message->to($companyEmail, $firstName)->subject('登録完了');
                $message->cc($backupEmail, $firstName)->subject('登録完了');
                $message->from(env('MAIL_USERNAME'),env('MAIL_FROM_NAME'));

            });
        } else {
            \Mail::send(['text'=>'mailJP'], $data, function($message) use ($companyEmail, $firstName) {
                $message->to($companyEmail, $firstName)->subject('登録完了');
                $message->from(env('MAIL_USERNAME'),env('MAIL_FROM_NAME'));

            });
        }
    }

    public function mailToUser_KR(
        string $firstName='', 
        string $lastName='', 
        string $companyName='',
        string $companyEmail='',
        string $backupEmail='',
        string $phoneNumber='',
        string $country='',
        // string $registeredSession='',
        // string $lunchOptions='',
        string $typeOfIndustry='',
        string $typeOfJob='',
        string $jobTitle='',
        string $trackOfInterest=''
        )
    {
        $data = array(
            'firstName' => $firstName,
            'lastName' => $lastName,
            'companyName' => $companyName,
            'companyEmail' => $companyEmail,
            'backupEmail' => $backupEmail,
            'phoneNumber' => $phoneNumber,
            'country' => $country,
            // 'registeredSession' => $registeredSession,
            // 'lunchOptions' => $lunchOptions,
            'typeOfIndustry' => $typeOfIndustry,
            'typeOfJob' => $typeOfJob,
            'jobTitle' => $jobTitle,
            'trackOfInterest' => $trackOfInterest,
        );

        if ($backupEmail) {
            \Mail::send(['text'=>'mailKR'], $data, function($message) use ($companyEmail, $firstName, $backupEmail) {
                $message->to($companyEmail, $firstName)->subject('등록 확인 메일');
                $message->cc($backupEmail, $firstName)->subject('등록 확인 메일');
                $message->from(env('MAIL_USERNAME'),env('MAIL_FROM_NAME'));

            });
        } else {
            \Mail::send(['text'=>'mailKR'], $data, function($message) use ($companyEmail, $firstName) {
                $message->to($companyEmail, $firstName)->subject('등록 확인 메일');
                $message->from(env('MAIL_USERNAME'),env('MAIL_FROM_NAME'));

            });
        }
    }
    
    public function mailToUser_EN(string $firstName='', string $companyEmail='', string $backupEmail='')
    {
        $data = array('name'=>$firstName);

        if ($backupEmail) {
            \Mail::send(['text'=>'mailEN'], $data, function($message) use ($companyEmail, $firstName, $backupEmail) {
                $message->to($companyEmail, $firstName)->subject('Registration is complete');
                $message->cc($backupEmail, $firstName)->subject('Registration is complete');
                $message->from(env('MAIL_USERNAME'),env('MAIL_FROM_NAME'));

            });
        } else {
            \Mail::send(['text'=>'mailEN'], $data, function($message) use ($companyEmail, $firstName) {
                $message->to($companyEmail, $firstName)->subject('Registration is complete');
                $message->from(env('MAIL_USERNAME'),env('MAIL_FROM_NAME'));

            });
        }
    }

}


